@@ -1,17 +1,14 @@
 import pigpio
 
 class GHFan(object):
-    """This class GHFan provides a services to control the IoT Greenhouse fan
+    """A class to access the IoT Greenhouse fan.
     """
     
     FAN_ON = True
     FAN_OFF = False
 
-    _pi = None
-    _gpio = 0
-        
     def __init__(self, pi, fan_gpio):
-        """Constructor for class GHFan
+        """Initializes the IoT Greenhouse fan.
         
         :param pi: reference to pigpio service
         :param fan_gpio: GPIO port for fan. Use GHgpio definitions.
@@ -25,21 +22,43 @@ class GHFan(object):
         self._pi.write(self._gpio, self.FAN_OFF)
         
     def on(self):
+        """Activates the fan.
+        """
         self._pi.write(self._gpio, self.FAN_ON)
         
     def off(self):
+        """Deactivates the fan.
+        """
         self._pi.write(self._gpio, self.FAN_OFF)
-        
+    
+    def toggle(self):
+        """Toggle fan state.
+        """
+        if self.is_on():
+            self.off()
+        else:
+            self.on()
+
     def get_state(self):
+        """Returns the current state of the fan.
+        """
         return self._pi.read(self._gpio)
 
     def is_on(self):
+        """Returns Boolean indicating fan is on.
+        """
         return self.get_state() == self.FAN_ON
 
     def is_off(self):
+        """Returns Boolean indicating fan is off.
+        """
         return self.get_state() == self.FAN_OFF
     
     def get_status(self):
+        """Gets status of fan.
+
+        :returns: Fan status as string.
+        """
         if self.get_state() == self.FAN_ON:
             return "ON"
         else:
