@@ -5,11 +5,11 @@ def test_post():
    
     print("*** GH testing ***")   
     ghs = IoTGreenhouseService()
-    gh = ghs.green_house
+    gh = ghs.greenhouse
     ghs.web_service.post_greenhouse()
-    print(gh.post_data.status_code)
-    print(gh.post_data.last_update)
-    print(gh.post_data.exception)
+    print(ghs.web_service.post_data.status_code)
+    print(ghs.web_service.post_data.last_update)
+    print(ghs.web_service.post_data.exception)
     print("GH post test completed.")   
 
 if __name__ == "__main__":
