@@ -84,17 +84,12 @@ def servo_test():
         sleep(1)
     print("Servo moves between min and max Turn toggle on to end.")
     while(ghs.switches.toggle.get_state() == ghs.switches.SWITCH_OFF):
-        pos = 0
-        while pos <= 1:
-            ghs.servo.move(pos)
-            pos += .1
-            sleep(.2)
         pos = 1
-        while pos > 0:
-            ghs.servo.move(pos)
-            pos -= .1
-            sleep(.2)
+        ghs.servo.move(pos)
+        sleep(2)
         pos = 0
+        ghs.servo.move(pos)
+        sleep(2)
     print("Servo test done.")
     print()
 
